@@ -6,23 +6,21 @@
  * 
  * Copyright (c) 2004 James Su <suzhe@tsinghua.org.cn>
  *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: scim_uim_imengine.cpp,v 1.10 2004/07/03 13:29:44 suzhe Exp $
+ * $Id: scim_uim_imengine.cpp,v 1.12 2005/08/08 03:08:34 suzhe Exp $
  */
 
 #define Uses_SCIM_UTILITY
@@ -51,7 +49,7 @@
     #define SCIM_UIM_ICON_FILE           (SCIM_ICONDIR "/scim-uim.png")
 #endif
 
-static const int   __uim_nr_uuids = 64;
+static const int   __uim_nr_uuids = 128;
 static const char *__uim_uuids [] = {
 "a7260f28-f634-49b9-bda0-9563e73dfdcc",
 "0f1c9e83-87ff-4d5b-b001-d26ed9eea28b",
@@ -116,7 +114,71 @@ static const char *__uim_uuids [] = {
 "08a98403-e50d-4f3e-a295-27464fa96c13",
 "afe96cee-73c3-4af3-aed6-a1c51e5974bc",
 "7c05965a-62f3-4d56-a82d-1e4b363fc5ab",
-"43fd4393-8425-4bd0-9ba4-8f0d71db7659"
+"43fd4393-8425-4bd0-9ba4-8f0d71db7659",
+"6e65c275-8c23-4642-91e9-6ea9ecbda41c",
+"ec7cde34-a3e3-4db6-bb36-6eea931e29d6",
+"051b61df-28fd-4b7d-92ba-af140a1cf62d",
+"0af548b8-7b5c-45de-8af1-444b9622bf2e",
+"f4986a51-7b16-4c9a-8b90-7d16a84dba87",
+"80358db4-c753-4337-a889-ea84d8135335",
+"adada64e-d5a8-4bf4-b5cf-b3b22ddc8bf8",
+"23c87d83-b581-4ad0-bc22-60d89d510586",
+"003a0e50-6bf4-4a40-8f79-6a71d2866061",
+"ef1d08d3-3d6e-4021-b191-1a5ee6a42cdd",
+"ccd8cd0e-5d9a-4d7c-a066-39defcac48a8",
+"224a288e-440d-4477-ae95-93dd80add396",
+"bcc3267a-2e3b-46cc-8b00-fcfe1de2dee0",
+"6cb55b24-0a19-4975-975e-90493eb03f20",
+"853cd53c-8520-426d-ab79-06eb5830f5c9",
+"1fb0a4d8-47da-4268-919c-f3ffcb0c6e55",
+"a4ce45ab-7bac-4a9a-b30b-cadabf510b1e",
+"1cb3271f-c661-46cb-b8b2-0e05a7f2f783",
+"03c5a6ea-2b14-4758-abf0-ee4463079501",
+"d44f68fd-62e9-497e-bb58-a1f1fa86a335",
+"99fa1c0a-5434-4432-951f-68a9003e4524",
+"6fba0759-93a6-49af-979c-ba5f542ef1b7",
+"961e550f-de34-44db-97cd-11374968aa85",
+"beb2cbf2-6499-4a23-8e41-8a66f98a0e52",
+"18e304a2-cf55-43ab-81f4-3b5035ffe592",
+"b43051d5-055b-4a5b-b4f8-2bd18396fc4e",
+"51daa0f3-cd21-426d-9262-20c5f8264827",
+"634ec9f1-01cb-4f7b-b350-c2713fe1b3ae",
+"b39d13b8-3660-4ab3-a29e-6b839e2a2cc8",
+"63310e02-2f33-4e6d-ad09-042248f1548c",
+"dbcd01fe-c673-4291-bd34-aa967e93056f",
+"aa47fd51-a9fc-4a22-a880-67f2ceaf4e51",
+"9795ce0e-8917-4eff-a8b0-97df4923b962",
+"3a941c8a-7296-4ba3-80e9-d217460fa284",
+"7d5edaf0-567d-4b18-bd9f-9298eaca5863",
+"3a70a0e8-9972-4b7e-9913-7fa66c858b39",
+"800d4437-7e1f-4602-8428-a8166810a519",
+"ffba4b45-c917-4877-a7fa-b4d598a8da3b",
+"e40141ad-0fcf-4d21-ae51-da7d5ce39132",
+"7f1ef850-ff54-45c0-82f3-48d329c74b25",
+"ec3dafdf-01b6-4e50-af5b-1d13bcad0a07",
+"90e5b710-a9be-4a51-9ee5-4ff246c7d905",
+"f4aa1d77-3319-47df-9c08-6e48bc64647b",
+"7e541494-c453-4ee6-b625-98b0d5918fdd",
+"9e8e1898-5803-487f-9934-f2543abc501b",
+"5915de02-33c0-40a3-a1fd-3a4736b1c519",
+"55dbc4f5-f4ea-4b5b-8890-a7413d7731f1",
+"78db4c98-324b-4a83-8fc7-1e6b4d6aef63",
+"c6ab096c-cf09-4642-841b-cc986cf83f49",
+"21475d28-c74f-4ea5-b323-d8e37c1c3f10",
+"422a2a17-a7ea-4a88-96ee-a22fdedcf25a",
+"a9069165-d399-406b-a3b6-94513d1fe5dd",
+"ad0d8f2f-0268-4c4f-b542-00c3cffdabf8",
+"429eecad-f904-427a-9132-7f198d3fc3e7",
+"a5d2fa81-5243-4798-a980-1eac5ffdfcaf",
+"5d9059aa-3daa-4a55-bae2-c7ff7787eb8a",
+"09bd8211-68c6-44db-99e6-33ffef0b195c",
+"3ea3a87b-835b-40f0-983d-5d296ba578a3",
+"44c02613-42e8-49a4-bdf6-f16e9fc5d7b8",
+"d61d2879-d3f7-4da1-aabf-c124641595e0",
+"430cbebd-56bc-45d0-b0c4-8f8fbe8e1590",
+"fd8f93df-0c91-49ec-9442-282dabc0d3d7",
+"ff053f70-ebc0-462a-a52d-559435d5d390",
+"a7027b54-ed6e-4656-80cc-3b1641853efa"
 };
 
 struct UIMInfo {
@@ -523,10 +585,10 @@ UIMInstance::convert_keymask (int mod)
     if (mod & SCIM_KEY_AltMask) {
         rv |= UMod_Alt;
     }
-    if (mod & SCIM_KEY_Mod3Mask) {  /* assuming mod3 */
+    if (mod & SCIM_KEY_SuperMask) {
         rv |= UMod_Super;
     }
-    if (mod & SCIM_KEY_Mod4Mask) {  /* assuming mod4 */
+    if (mod & SCIM_KEY_HyperMask) {
         rv |= UMod_Hyper;
     }
     return rv;
@@ -760,6 +822,40 @@ UIMInstance::uim_cand_deactive_cb (void *ptr)
         this_ptr->m_show_lookup_table = false;
     }
 }
+
+void
+UIMInstance::uim_surrounding_text_request_cb (void *ptr)
+{
+    UIMInstance *this_ptr = static_cast <UIMInstance *> (ptr);
+    if (this_ptr) {
+
+        SCIM_DEBUG_IMENGINE(2) << "uim_surrounding_text_request_cb.\n";
+
+        WideString wstr;
+        int cursor;
+
+        if (this_ptr->get_surrounding_text (wstr, cursor)) {
+            String str = utf8_wcstombs (wstr);
+            uim_set_surrounding_text (this_ptr->m_uc, str.c_str (), cursor, wstr.length ());
+        }
+    }
+}
+
+int
+UIMInstance::uim_surrounding_text_delete_cb  (void *ptr, int offset, int len)
+{
+    UIMInstance *this_ptr = static_cast <UIMInstance *> (ptr);
+    int ret = -1;
+
+    if (this_ptr) {
+        SCIM_DEBUG_IMENGINE(2) << "uim_surrounding_text_delete_cb.\n";
+        
+        if (this_ptr->delete_surrounding_text (offset, len))
+            ret = 0;
+    }
+
+    return ret;
+}
 /*
 vi:ts=4:nowrap:ai:expandtab
 */
